#[non_exhaustive]pub enum PermissionsError {
Collision {
collision_count: usize,
hash_id: u64,
permissions: Vec<String>,
},
}Expand description
Permission-domain errors.
Use these errors when the permission system detects an unsafe or invalid condition, such as a collision between permission names.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Collision
Permission collision detected when multiple permissions hash to the same value.
Implementations