PermissionMappingError

Enum PermissionMappingError 

pub enum PermissionMappingError {
    IdMismatch {
        normalized_string: String,
        provided_id: u64,
        expected_id: u64,
    },
}
Errors that can occur when constructing or validating permission mappings.

Variants



IdMismatch

The provided permission ID doesn’t match the normalized string.

Fields

normalized_string: String

The normalized permission string that was used for ID computation

provided_id: u64

The permission ID that was provided

expected_id: u64

The permission ID that should have been computed from the normalized string